@@ -221,7 +221,7 @@ class timekprPlayTimeConfig(object):
                 # check if we have it
                 if userId not in self._cachedPids[self._USRS]:
                     # verify
-                    if userhelper.isUserValid(int(userId)):
+                    if userhelper.isUserValid(int(userId), pValidateUIDOnly=True):
                         # initialize set
                         self._initUserData(userId)
                     else:
@@ -335,7 +335,7 @@ class timekprPlayTimeConfig(object):
         rpids += len(pids)
 
         # extra log
-        if log.getLogLevel() == cons.TK_LOG_LEVEL_EXTRA_DEBUG:
+        if log.isDebugEnabled(cons.TK_LOG_LEVEL_EXTRA_DEBUG):
             # users
             for rUser in self._cachedPids[self._USRS]:
                 # print processes
@@ -350,13 +350,13 @@ class timekprPlayTimeConfig(object):
             # if trying to terminate
             if not pKill:
                 # logging
-                log.log(cons.TK_LOG_LEVEL_INFO, "sending terminate signal to process %s" % (pPid))
+                log.log(cons.TK_LOG_LEVEL_WARN, "sending terminate signal to process %s" % (pPid))
                 # terminate
                 psutil.Process(pid=int(pPid)).terminate()
             # now just kill
             else:
                 # logging
-                log.log(cons.TK_LOG_LEVEL_INFO, "sending kill signal to process %s" % (pPid))
+                log.log(cons.TK_LOG_LEVEL_WARN, "sending kill signal to process %s" % (pPid))
                 # kill
                 psutil.Process(pid=int(pPid)).kill()
         except:
@@ -373,7 +373,7 @@ class timekprPlayTimeConfig(object):
         # if we have user
         if pUid in self._cachedPids[self._USRS]:
             # extra log
-            if not pSilent and log.getLogLevel() == cons.TK_LOG_LEVEL_DEBUG:
+            if not pSilent and log.isDebugEnabled():
                 # logging
                 log.log(cons.TK_LOG_LEVEL_DEBUG, "PT: user \"%s\" (%s) has %i matching processes out of %i, using %i filters" % (pUname, pUid, len(self._cachedPids[self._USRS][pUid][self._MPIDS]), len(self._cachedPids[self._USRS][pUid][self._PIDS]), len(self._cachedPids[self._USRS][pUid][self._FLTS])))
             # result
@@ -422,9 +422,9 @@ class timekprPlayTimeConfig(object):
                 # remove brackets "[]" because we use them as description
                 flt = flt.replace("[", "").replace("]", "")
                 # add precompiled filters
-                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile("^%s$" % (flt)))
-                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile("[/\\\\]%s$" % (flt)))
-                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile("[/\\\\]%s " % (flt)))
+                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile(r"^%s$" % (flt)))
+                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile(r"[/\\]%s$" % (flt)))
+                self._cachedPids[self._USRS][pUid][self._FLTS][rFlt].append(re.compile(r"[/\\]%s " % (flt)))
                 # add matched pids to to matched pid list
                 self._cachedPids[self._USRS][pUid][self._MPIDS].update(self._getMatchedProcessesByFilter(pUid, self._cachedPids[self._USRS][pUid][self._FLTS][rFlt], self._cachedPids[self._USRS][pUid][self._PIDS]))
 
@@ -433,7 +433,7 @@ class timekprPlayTimeConfig(object):
         # if we have user
         if pUid in self._cachedPids[self._USRS]:
             # logging
-            log.log(cons.TK_LOG_LEVEL_INFO, "killing %i PT processes for uid \"%s\" " % (len(self._cachedPids[self._USRS][pUid][self._MPIDS]), pUid))
+            log.log(cons.TK_LOG_LEVEL_WARN, "killing %i PT processes for uid \"%s\" " % (len(self._cachedPids[self._USRS][pUid][self._MPIDS]), pUid))
             # terminate / kill all user PT processes
             for rPid in self._cachedPids[self._USRS][pUid][self._MPIDS]:
                 # increase terminate attempts
